@@ -88,7 +88,7 @@ class TerraformTemplateProcessor(TemplateProcessor):
                 terraform_template_parser = TerraformTemplateParser(template_file_path,parameter_file=parameter_file_list)
                 template_json = terraform_template_parser.parse()
 
-                self.template_file = terraform_template_parser.template_file_list
+                self.template_files = terraform_template_parser.template_file_list
                 self.parameter_files = terraform_template_parser.parameter_file_list
 
         return template_json
\ No newline at end of file
